global angles           % Angular configuration (deg): global variable.
if isempty(angles),
    angles=[0;0;0;0];
end
disp(['Angular configuration: ',num2str(angles')])
%------------------------------------------------------------------------
% DATABANK.m : file of satellite definition
%
% Definition of
%   Main Body : MB : structure
%   Number of flexible appendages : nappend
%   appendage SA{i} : structure 
%------------------------------------------------------------------------

% Frames definition :
%-------------------------
% (0,X,Y,Z) : reference frame attached to Main Body (satellite axes)
% (Pi,Xi,Yi,Zi) : frame related to the appendage SA{i} at point Pi,
%                 with Pi = SA{i}.P coordinate vector of the connecting point between appendage
%                 SA{i} and main body MB (expressed in frame (0,X,Y,Z)).
% (CGi,Xi,Yi,Zi) : frame related to the appendage SA{i} at its center of mass CGi,
%                 with CGi = SA{i}.cg coordinate vector of CGi (expressed in frame (Pi,Xi,Yi,Zi)).
%=====================================================================
% Central Body : MB :
%---------------------
MB.Name='Platform';              % Name of the body
MB.cg = [0;0;0];                 % position of gravity center
                                 % in (0,X,Y,Z) (m)
MB.m = 20;                       % mass (kg)
MB.Ixx = 5;                      % Main Inertia in
MB.Iyy = 5;                      % (cg,X,Y,Z)
MB.Izz = 10;                     % (kgm^2)
MB.Ixy = 0;                      % Cross Inertia in
MB.Ixz = 0;                      % (cg,X,Y,Z)
MB.Iyz = 0;                      % (kgm^2)
%==========================================================================

% Number of appendages :
%--------------------------------
nappend = 4; 

%==========================================================================
SA{1}.Name = 'CMG #1';         % Name of appendage 1
SA{1}.P = [0.5;0;0];           % position of connection point P1
                               % in (0,X,Y,Z) (m)
SA{1}.TM = [ cos(2*pi/6)   0 -sin(2*pi/6)   % this is the transformation matrix associated with 
             0             1           0    % the rotation from main body reference frame (X,Y,Z)
             sin(2*pi/6)   0 cos(2*pi/6)];  % to appendage frame (X1, Y1, Z1). (that is the 3x3 matrix
                                            % of vectors X1, Y1 and Z1 coordinates in frame (X,Y,Z).
SA{1}.pivot = 1;               % if ==1, then pivot joint between appendage and main body at point P1
                               % around (P1,z1) axis.
                               % if ==0 then cantilevered joint.
                                
SA{1}.angle = angles(1);       % Nominal rotation (degree) around the pivot axis.
                                   
SA{1}.filename='dataCMG';      % Appendage data are given in a file
%==========================================================================
SA{2}.Name = 'CMG #2';         % Name of appendage 2
SA{2}.P = [-0.5;0;0];          % position of connection point P2
                               % in (0,X,Y,Z) (m)
SA{2}.TM = [ -cos(2*pi/6)   0 sin(2*pi/6)   % this is the transformation matrix associated with 
             0             1           0    % the rotation from main body reference frame (X,Y,Z)
             sin(2*pi/6)   0 cos(2*pi/6)];  % to appendage frame (X2, Y2, Z2). (that is the 3x3 matrix
                                            % of vectors X2, Y2 and Z2 coordinates in frame (X,Y,Z).
SA{2}.pivot = 1;               % if ==1, then pivot joint between appendage and main body at point P2
                               % around (P2,z2) axis.
                               % if ==0 then cantilevered joint.
                                
SA{2}.angle = angles(2);       % Nominal rotation (degree) around the pivot axis.
                                   
SA{2}.filename='dataCMG';      % Appendage data are given in a file
%==========================================================================
SA{3}.Name = 'CMG #3';         % Name of appendage 3
SA{3}.P = [0;0.5;0];           % position of connection point P3
                               % in (0,X,Y,Z) (m)
Mz=[0 -1 0;1 0 0;0 0 1];
SA{3}.TM = [ 1           0                0   % this is the transformation matrix associated with 
             0      cos(2*pi/6) -sin(2*pi/6)   % the rotation from main body reference frame (X,Y,Z)
             0      sin(2*pi/6)  cos(2*pi/6)]*Mz;  % to appendage frame (X3, Y3, Z3). (that is the 3x3 matrix
                                                     % of vectors X3, Y3 and Z3 coordinates in frame (X,Y,Z).
SA{3}.pivot = 1;               % if ==1, then pivot joint between appendage and main body at point P3
                               % around (P3,z3) axis.
                               % if ==0 then cantilevered joint.
                                
SA{3}.angle = angles(3);       % Nominal rotation (degree) around the pivot axis.
                                   
SA{3}.filename='dataCMG';      % Appendage data are given in a file
%==========================================================================
SA{4}.Name = 'CMG #4';         % Name of appendage 4
SA{4}.P = [0;-0.5;0];          % position of connection point P4
                               % in (0,X,Y,Z) (m)
SA{4}.TM = [ 1           0                0   % this is the transformation matrix associated with 
             0     -cos(2*pi/6)  sin(2*pi/6)   % the rotation from main body reference frame (X,Y,Z)
             0      sin(2*pi/6)  cos(2*pi/6)]*Mz;  % to appendage frame (X4, Y4, Z4). (that is the 3x3 matrix
                                                   % of vectors X4, Y4 and Z4 coordinates in frame (X,Y,Z).
SA{4}.pivot = 1;               % if ==1, then pivot joint between appendage and main body at point P4
                               % around (P4,z4) axis.
                               % if ==0 then cantilevered joint.
                                
SA{4}.angle = angles(4);       % Nominal rotation (degree) around the pivot axis.
                                   
SA{4}.filename='dataCMG';      % Appendage data are given in a file

