% This package contains basic functions to compute the (direct and indirect) linear dynamic model
% of spacecraft:
%
%  * MAIN is the main function,
%  * TRANSLATE_DYNAMIC_MODEL: to translate a dynamic from one point to another,
%  * ROTATE_DYNAMIC_MODEL: to rotate a dynamic model,
%  * KINEMATIC_MODEL: to compute the kinematic model between 2 points of a body,
%  * ANTISYM: to compute the antisymetric matrix associated with a vector.
%  
% This package contains also example data files:
%
%  * Spacecraft1.m is a data file relative to a spacecraft composed of a main body
%    and two flexible appendage cantilevered on the main body,
%
%  * Spacecraft2.m is the same than \verb+Spacecraft1.m+ but the first appendage is 
%    connected to the main body through a pivot joint and tilted with a 10 degres angle,
%
%  * Spacecraft3.m is another data file describing the same spacecraft as Spacecraft2.m but
%      using recursive call to MAIN function. Spacecraft3.m calls data file APPENDAGE1
%      to describe the first flexible appendage.
%      
%      EXAMPLE:
% >>   mod1=main('Spacecraft2');
% >>   mod2=main('Spacecraft3');
% >>   figure,sigma(mod1.DynamicModel-mod2.DynamicModel)
%      
%  * Spacecraft4.m is another data file for another spacecraft composed of a main body
%    and 3 appendages: the same 2 appendages as Spacecraft2.m + a third appendage described
%    by data file Spacecraft3.
%
%  * Spacecraft5.m is the same than \verb+Spacecraft1.m+ but with 3 additionnal
%    appendages corresponding to angular momentums along to X, Y and Z axes
%    (to represent spinned RWA)
%     
%  * FOUR_CMGs.m is a data file describing a platform fitting with four identical
%       CMGs. The CMG is decribed by the data file dataCMG.m. These data
%       correspond roughly to the experimental CMG platform TETRAGYRE developped by
%       ONERA/DCSD and presented at:
%       http://www.onera.fr/dcsd/gyrodynes/
%       
%  * SpaceRoboticArm.m is a date file describing a platform fitting a 6 d.o.f. rigid
%    space robotic arm: the 6 links of the arm are described in the files Segment1.m,
%    Segment2.m, ..., Segment6.m.
%    EXAMPLE:
% >> mod=main('SpaceRoboticArm');
% >> mod.liste_IOs   % To list and see the order of inputs and outputs of models
%
%  * Spacecraft1u.m is another data file describing the same structure thab Spacecraft1.m but
%    the main mechanical parameters are uncertain and defined by the function UREAL.
%    Then, the outputs of the toolbox main function are uncertain elements, matrices or 
%    models, compatible with the \matlab Robust Control Toolbox (LFT).
%    EXAMPLE:
% >> mod=main('Spacecraft1u');
% >> mod.DynamicModel
%    
% see also: demoSDT

