global config           % Angular configuration (deg): global variable.
%**************************************************************************
% Segment2.m : file of second segment definition for Canadarm
%--------------------------------------------------------------------------
% Definition of
%   Main Body : MB : structure
%   Number of appendages : nappend
%   Appendage SA{i} : structure 
%**************************************************************************

%==========================================================================
% FRAMES DEFINITION
%--------------------------------------------------------------------------
% (O,X,Y,Z)     : reference frame attached to Main Body  (here: segment 2)
% (Pi,Xi,Yi,Zi) : frame related to the appendage SA{i} at point Pi,
%                 with Pi = SA{i}.P coordinate vector of the connecting 
%                 point between appendage SA{i} and main body MB (expressed
%                 in frame (O,X,Y,Z)). 
%==========================================================================


%==========================================================================
% CENTRAL BODY : MB     
% (Cylindrical Segment of length 6.38m, radius 0.15m, mass 115kg)
%--------------------------------------------------------------------------
MB.cg = [3.19;0;0];         % position of gravity center in (0,X,Y,Z) (m)

MB.m = 115;                 % mass (kg)
MB.Ixx = 1.2938;            % Main Inertia in (cg,X,Y,Z)(kg.m^2)
MB.Iyy = 390.73;            % 
MB.Izz = 390.73;            % 
MB.Ixy = 0;                 % Cross Inertia in (cg,X,Y,Z) (kg.m^2)
MB.Ixz = 0;                 % 
MB.Iyz = 0;                 % 

nappend = 1;                % Number of appendages

%==========================================================================
% APPENDAGE 1 : SA{1}
% (Following Segment)
%--------------------------------------------------------------------------
SA{1}.Name = 'Link#3';      % Name of the third link of the robotic arm
SA{1}.P = [6.38;0;0];       % position of connection point P1 in (0,X,Y,Z) (m)
                            
SA{1}.TM = eye(3);          % transition matrix from (X,Y,Z) to (X1,Y1,Z1)
                                                       
SA{1}.pivot = 1;            % Case: 1 - pivot joint along (P1,Z1) axiz
                            %       0 - cantilevered joint

SA{1}.angle = config(3);    % Nominal rotation (degree) around the pivot axis.

%--------------------------- SUBAPPENDAGES DATA ---------------------------
SA{1}.filename = 'Segment3';
%==========================================================================
