global config           % Angular configuration (deg): global variable.
%**************************************************************************
% Segment4.m : file of forth segment definition for Canadarm
%--------------------------------------------------------------------------
% Definition of
%   Main Body : MB : structure
%   Number of appendages : nappend
%   Appendage SA{i} : structure 
%**************************************************************************

%==========================================================================
% FRAMES DEFINITION
%--------------------------------------------------------------------------
% (O,X,Y,Z)     : reference frame attached to Main Body (here: segment 4)
% (Pi,Xi,Yi,Zi) : frame related to the appendage SA{i} at point Pi,
%                 with Pi = SA{i}.P coordinate vector of the connecting 
%                 point between appendage SA{i} and main body MB (expressed
%                 in frame (O,X,Y,Z)). 
%==========================================================================


%==========================================================================
% CENTRAL BODY : MB     
% (Cylindrical Segment of length 0.63m, radius 0.15m, mass 40kg)
%--------------------------------------------------------------------------
MB.cg = [0.315;0;0];        % position of gravity center in (0,X,Y,Z) (m)

MB.m = 40;                  % mass (kg)
MB.Ixx = 0.4500;            % Main Inertia in (cg,X,Y,Z)(kg.m^2)
MB.Iyy = 1.5480;            % 
MB.Izz = 1.5480;            % 
MB.Ixy = 0;                 % Cross Inertia in (cg,X,Y,Z) (kg.m^2)
MB.Ixz = 0;                 % 
MB.Iyz = 0;                 % 

nappend = 1;                % Number of appendages

%==========================================================================
% APPENDAGE 1 : SA{1}
% (Following Segment)
%--------------------------------------------------------------------------
SA{1}.Name = 'Link#5';      % Name of the 5-th link of the robotic arm
SA{1}.P = [0.63;0;0];       % position of connection point P1 in (0,X,Y,Z) (m)
                            
SA{1}.TM = [ 1 0                0                  % transformation matrix for the rotation from 
             0 cos(-90*pi/180) -sin(-90*pi/180)    % MB frame (X,Y,Z) to appendage frame (X1, Y1, Z1).   
             0 sin(-90*pi/180)  cos(-90*pi/180)];  % (that is the 3x3 matrix of X1,Y1,Z1 coordinates
                                                   % in frame (X,Y,Z) )
                                                       
SA{1}.pivot = 1;            % Case: 1 - pivot joint along (P1,Z1) axiz
                            %       0 - cantilevered joint

SA{1}.angle = config(5);    % Nominal rotation (degree) around the pivot axis.

%--------------------------- SUBAPPENDAGES DATA ---------------------------
SA{1}.filename = 'Segment5';
%==========================================================================
