global config           % Angular configuration (deg): global variable.
if isempty(config),
    config=[0;30;120;0;0;0];
end
disp(['Angular configuration: ',num2str(config')])
%**************************************************************************
% SpaceRoboticArm.m : file of satellite + robotic arm definition
%
% Vincent Dublanchet, Davis Saussié and Daniel Alazard
%--------------------------------------------------------------------------
% Definition of
%   Main Body : MB : structure
%   Number of appendages : nappend
%   Appendage SA{i} : structure 
%**************************************************************************

%==========================================================================
% FRAMES DEFINITION
%--------------------------------------------------------------------------
% (0,X,Y,Z)      : reference frame attached to Main Body (satellite axes)
% (Pi,Xi,Yi,Zi)  : frame related to the appendage SA{i} at point Pi,
%                  with Pi = SA{i}.P coordinate vector of the connecting 
%                  point between appendage SA{i} and main body MB (expressed
%                  in frame (0,X,Y,Z)). 
% (CGi,Xi,Yi,Zi) : frame related to the appendage SA{i} at its center of 
%                  mass CGi, with CGi = SA{i}.cg coordinate vector of CGi 
%                  (expressed in frame (Pi,Xi,Yi,Zi)).
%==========================================================================

%==========================================================================
% CENTRAL BODY : MB     
% (Box of 2m side length)
%--------------------------------------------------------------------------
MB.Name='Main_body';             % Name of the body
MB.cg = [0;0;0];                 % position of gravity center in (0,X,Y,Z) (m)
                                 % 
MB.m = 1000;                     % mass (kg)
MB.Ixx = MB.m*2^2/6;             % Main Inertia in (cg,X,Y,Z) (kg.m^2)
MB.Iyy = MB.m*2^2/6;             % 
MB.Izz = MB.m*2^2/6;             % 
MB.Ixy = 0;                      % Cross Inertia in (cg,X,Y,Z) (kg.m^2)
MB.Ixz = 0;                      % 
MB.Iyz = 0;                      % 

% Number of appendages :
nappend = 1; 
%==========================================================================


%==========================================================================
% APPENDAGE 1 : SA{1} 
% (First Segment of the Robotic Arm)
%--------------------------------------------------------------------------
SA{1}.Name = 'Link#1';         % Name of the first link of the robotic arm
SA{1}.P  = [0;0;1];            % position of connection point P1 in (0,X,Y,Z) (m)

SA{1}.TM = [ cos(-90*pi/180)   -sin(-90*pi/180)   0    % transformation matrix for the rotation from 
             sin(-90*pi/180)    cos(-90*pi/180)   0    % MB frame (X,Y,Z) to appendage frame (X1, Y1, Z1). 
             0                  0                 1];  % (that is the 3x3 matrix of X1,Y1,Z1 coordinates
                                                       % in frame (X,Y,Z) )
SA{1}.pivot = 1;               % if == 1, then pivot joint between appendage 
                               %          and main body at P1 around (P1,z1) axis.
                               % if == 0, then cantilevered joint.
                                
SA{1}.angle = config(1);       % Nominal rotation (degree) around the pivot axis.
          

%--------------------------- SUBAPPENDAGES DATA ---------------------------
SA{1}.filename = 'Segment1';
%==========================================================================



