%------------------------------------------------------------------------
% Spacecraft2.m : file of satellite definition
%
% Definition of
%   Main Body : MB : structure
%   Number of flexible appendages : nappend
%   appendage SA{i} : structure 
%------------------------------------------------------------------------

% Frames definition :
%-------------------------
% (0,X,Y,Z) : reference frame attached to Main Body (satellite axes)
% (Pi,Xi,Yi,Zi) : frame related to the appendage SA{i} at point Pi,
%                 with Pi = SA{i}.P coordinate vector of the connecting point between appendage
%                 SA{i} and main body MB (expressed in frame (0,X,Y,Z)).
% (CGi,Xi,Yi,Zi) : frame related to the appendage SA{i} at its center of mass CGi,
%                 with CGi = SA{i}.cg coordinate vector of CGi (expressed in frame (Pi,Xi,Yi,Zi)).
%=====================================================================
% Central Body : MB :
%---------------------
MB.Name='Platform';              % Name of the body
MB.cg = [0;0;0];                 % position of gravity center
                                 % in (0,X,Y,Z) (m)
MB.m = 100;                      % mass (kg)
MB.Ixx = 10;                     % Main Inertia in
MB.Iyy = 10;                     % (cg,X,Y,Z)
MB.Izz = 20;                     % (kgm^2)
MB.Ixy = 0;                      % Cross Inertia in
MB.Ixz = 0;                      % (cg,X,Y,Z)
MB.Iyz = 0;                      % (kgm^2)
%==========================================================================

% Number of appendages :
%--------------------------------
nappend = 2; 

%==========================================================================
SA{1}.Name = 'Solar Array';    % Name of appendage 1
SA{1}.P = [0;1;0];             % position of connection point P1
                               % in (0,X,Y,Z) (m)
SA{1}.TM = [ cos(25*pi/180)   -sin(25*pi/180)   0    % this is the transformation matrix associated with 
             sin(25*pi/180)    cos(25*pi/180)   0    % the rotation from main body reference frame (X,Y,Z)
             0                 0                1];  % to appendage frame (X1, Y1, Z1). (that is the 3x3 matrix
                                                     % of vectors X1, Y1 and Z1 coordinates in frame (X,Y,Z).
SA{1}.pivot = 1;               % if ==1, then pivot joint between appendage and main body at point P1
                               % around (P1,z1) axis.
                               % if ==0 then cantilevered joint.
                               % if ==1, then pivot joint between appendage and main body at point P1                               

SA{1}.pivotdir = [0;0;2];      % Direction of pivot axis in appendage frame (X1,Y1,Z1).
                               % 3x1 vector: not necessary a unit vector.
                               % Cannot be  an uncertain parameter!
                               % default value: SA{i}.pivotdir = [0;0;1].

SA{1}.angle = 10;              % Nominal rotation (degree) around the pivot axis.
                                   
SA{1}.cg = [1;0;0];            % position of gravity center CG1
                               % in (P1,X1,Y1,Z1) (m)

SA{1}.m = 50;                  % mass (kg)
SA{1}.Ixx = 10;                % Main Inertia in
SA{1}.Iyy = 15;                % (CG1,X1,Y1,Z1) (kgm^2)
SA{1}.Izz = 20;
SA{1}.Ixy = 0;                 % Cross Inertia in
SA{1}.Ixz = 0;                 % (CG1,X1,Y1,Z1) (kgm^2)
SA{1}.Iyz = 0;

SA{1}.flex=2;                  % SA{1}.flex=0   ==> Appendage 1 is rigid
                               % SA{1}.flex=1   ==> Appendage 1 is flexible
                               %                with modal participations
                               %                SA{1}.L given at point CG1.
                               % SA{1}.flex=2   ==> Appendage 1 is flexible
                               %                with modal participations
                               %                SA{1}.L given at point P1.
                              
%----------------- FLEXIBILITY DATA OF APPENDAGE 1  -----------------------
%  Modal Participations :                               
SA{1}.L(1,:) = (25^0.5)*[(2^0.5)/2 (2^0.5)/2  0        0 0 0];
SA{1}.L(2,:) = (25^0.5)*[0         (2^0.5)/2 (2^0.5)/2 0 0 0];
SA{1}.L(3,:) = (10^0.5) *[0         0          0        0 0 1]; 

SA{1}.wi = [8 15 20] ;             % flexible mode pulsations (rd/s)

SA{1}.z  = [0.005 0.005 0.005] ;   % flexible mode damping ratios

%==========================================================================
SA{2}.Name = 'Antenna';        % Name of appendage 2
SA{2}.P = [0;-1;0];            % POINT P2 is given in (0,X,Y,Z)
SA{2}.TM = [  cos(40*pi/180) -sin(40*pi/180)   0   % Transition matrix from main body reference frame (X,Y,Z)
              sin(40*pi/180)  cos(40*pi/180)   0   % reference frame (X,Y,Z) to appendage frame (X2,Y2,Z2).
             0                0                1]; 
SA{2}.pivot = 0;
SA{2}.cg = [0;1;0];              % position of gravity center CG2
                                 % in (P2,X2,Y2,Z2)
SA{2}.m = 20;
SA{2}.Ixx = 4;                   % Main Inertia in
SA{2}.Iyy = 4;                   % (CG2,X2,Y2,Z2) (kgm^2)
SA{2}.Izz = 5;
SA{2}.Ixy = 0;                   % Cross Inertia in
SA{2}.Ixz = 0;                   % (CG2,X2,Y2,Z2) (kgm^2)
SA{2}.Iyz = 0;

SA{2}.flex=2;                    % Appendage 2 is flexible
%----------------- FLEXIBILITY DATA OF APPENDAGE 2  -----------------------
%  Modal Participations :                               
SA{2}.L(1,:) = (10^0.5)*[(2^0.5)/2 (2^0.5)/2  0        0 0 0];
SA{2}.L(2,:) = (10^0.5)*[ 0        (2^0.5)/2 (2^0.5)/2 0 0 0];
SA{2}.L(3,:) = (2^0.5) *[ 0         0          0       0 0 1]; 

SA{2}.wi = [8 15 20] ;            % flexible mode pulsations (rd/s)

SA{2}.z  = [0.005 0.005 0.005];   % flexible mode damping ratios

%==========================================================================



