% DM_OUT = ROTATE_DYNAMIC_MODEL (DM_IN , ANGLE, AXIS)
% computes the dynamic model after a rotation of ANGLE (deg) 
% around the axis AXIS :
%   * DN_IN:  dynamic model of a body in a frame R,
%   * ANGLE:  rotation angle (deg),
%   * AXIS:   3 components in the frame R of the unitary vector 
%     along the rotation axis,
%   * DN_OUT: dynamic model of the rotated body in the frame R.
%
% It is assumed that the first 6x6 block of DM represent the dynamic model
% between the 6 dof acceleration vector and the 6 dof external force
% vector.
function DM_out = rotate_dynamic_model(DM_in,degrees,V)
theta= degrees*pi/360;
Mpass=quat2dcm([cos(theta) V(1)*sin(theta) V(2)*sin(theta) V(3)*sin(theta)])';
rot6=[Mpass zeros(3,3);zeros(3,3) Mpass];
DM_out = mydaug(rot6,eye(size(DM_in,1)-6))*DM_in*mydaug(rot6',eye(size(DM_in,2)-6));
