% TDM = TRANSLATE_DYNAMIC_MODEL(vec_A,vec_B,DM) translate the direct
% dynamic model from point A to point B in the same reference frame.
%   Inputs:
%    * vec_A: 3x1 coordinate vector of point A,
%    * vec_B: 3x1 coordinate vector of point B,
%    * DM:  dynamic model at point A.
%   Output:
%    * TDM: dynamic model at point B.
%
% It is assumed that the first 6x6 block of DM represent the dynamic model
% between the 6 dof acceleration vector and the 6 dof external force
% vector.

function TDM_out = translate_dynamic_model ( point_a , point_b , DM_in )
KM = kinematic_model (point_a , point_b);
TDM_out = mydaug(KM',eye(size(DM_in,1)-6))*DM_in*mydaug(KM,eye(size(DM_in,2)-6));
if isuncertain(TDM_out), TDM_out = simplify(TDM_out,'full');end
%TDM_out = KM'*DM_in* KM; %
%--------------------------------------------------------------------------
